pub struct Hashcrypt { /* private fields */ }Expand description
Hash-Crypt peripheral
Implementations
Sourceimpl Hashcrypt
impl Hashcrypt
pub const unsafe fn from_ptr(ptr: *mut ()) -> Self
pub const fn as_ptr(&self) -> *mut ()
Sourcepub const fn ctrl(self) -> Reg<Ctrl, RW>
pub const fn ctrl(self) -> Reg<Ctrl, RW>
Control register to enable and operate Hash and Crypto
Sourcepub const fn intenset(self) -> Reg<Intenset, RW>
pub const fn intenset(self) -> Reg<Intenset, RW>
Write 1 to enable interrupts; reads back with which are set.
Sourcepub const fn memaddr(self) -> Reg<Memaddr, RW>
pub const fn memaddr(self) -> Reg<Memaddr, RW>
Address to start memory access from (if available).
Sourcepub const fn config(self) -> Reg<Config, RW>
pub const fn config(self) -> Reg<Config, RW>
Returns the configuration of this block in this chip - indicates what services are available.